<?php
/**
 * Declaring widgets
 *
 * @package sgds
 */

/**
 * Add filter to the parameters passed to a widget's display callback.
 * The filter is evaluated on both the front and the back end!
 *
 * @link https://developer.wordpress.org/reference/hooks/dynamic_sidebar_params/
 */
add_filter( 'dynamic_sidebar_params', 'sgds_widget_classes' );
if ( ! function_exists( 'sgds_widget_classes' ) ) {
	/**
	 * Count number of visible widgets in a sidebar and add classes to widgets accordingly,
	 * so widgets can be displayed one, two, three or four per row.
	 *
	 * @global array $sidebars_widgets
	 *
	 * @param array $params {
	 *     @type array $args  {
	 *         An array of widget display arguments.
	 *
	 *         @type string $name          Name of the sidebar the widget is assigned to.
	 *         @type string $id            ID of the sidebar the widget is assigned to.
	 *         @type string $description   The sidebar description.
	 *         @type string $class         CSS class applied to the sidebar container.
	 *         @type string $before_widget HTML markup to prepend to each widget in the sidebar.
	 *         @type string $after_widget  HTML markup to append to each widget in the sidebar.
	 *         @type string $before_title  HTML markup to prepend to the widget title when displayed.
	 *         @type string $after_title   HTML markup to append to the widget title when displayed.
	 *         @type string $widget_id     ID of the widget.
	 *         @type string $widget_name   Name of the widget.
	 *     }
	 *     @type array $widget_args {
	 *         An array of multi-widget arguments.
	 *
	 *         @type int $number Number increment used for multiples of the same widget.
	 *     }
	 * }
	 * @return array $params
	 */
	function sgds_widget_classes( $params ) {
		global $sidebars_widgets;
		/*
		 * When the corresponding filter is evaluated on the front end
		 * this takes into account that there might have been made other changes.
		 */
		$sidebars_widgets_count = apply_filters( 'sidebars_widgets', $sidebars_widgets );
		// Only apply changes if sidebar ID is set and the widget's classes depend on the number of widgets in the sidebar.
		if ( isset( $params[0]['id'] ) && strpos( $params[0]['before_widget'], 'dynamic-classes' ) ) {
			$sidebar_id   = $params[0]['id'];
			$widget_count = count( $sidebars_widgets_count[ $sidebar_id ] );
			$widget_classes = 'widget-count-' . $widget_count;
			$widget_classes .= ' col';
			// if ( 0 === $widget_count % 4 || $widget_count > 6 ) {
			// 	// Four widgets per row if there are exactly four or more than six.
			// 	$widget_classes .= ' is-3';
			// } elseif ( 6 === $widget_count ) {
			// 	// If two widgets are published.
			// 	$widget_classes .= ' col-md-2';
			// } elseif ( $widget_count >= 3 ) {
			// 	// Three widgets per row if there's three or more widgets.
			// 	$widget_classes .= ' col-md-4';
			// } elseif ( 2 === $widget_count ) {
			// 	// If two widgets are published.
			// 	$widget_classes .= ' col-md-6';
			// } elseif ( 1 === $widget_count ) {
			// 	// If just on widget is active.
			// 	$widget_classes .= ' col-md-12';
			// }
			// Replace the placeholder class 'dynamic-classes' with the classes stored in $widget_classes.
			$params[0]['before_widget'] = str_replace( 'dynamic-classes', $widget_classes, $params[0]['before_widget'] );
		}
		return $params;
	}
} // endif function_exists( 'sgds_widget_classes' ).
add_action( 'widgets_init', 'sgds_widgets_init' );

if ( ! function_exists( 'sgds_widgets_init' ) ) {
	/**
	 * Initializes themes widgets.
	 */
	function sgds_widgets_init() {
		// register_sidebar(
		// 	array(
		// 		'name'          => __( 'Right Sidebar', 'sgds' ),
		// 		'id'            => 'right-sidebar',
		// 		'description'   => __( 'Right sidebar widget area', 'sgds' ),
		// 		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		// 		'after_widget'  => '</aside>',
		// 		'before_title'  => '<h3 class="widget-title">',
		// 		'after_title'   => '</h3>',
		// 	)
		// );
		register_sidebar(
			array(
				'name'          => __( 'Left Sidebar', 'sgds' ),
				'id'            => 'left-sidebar',
				'description'   => __( 'Left sidebar widget area', 'sgds' ),
				'before_widget' => '<aside id="%1$s" class="sgds-menu"><ul class="sgds-menu-list"',
				'after_widget'  => '</ul></aside>',
				'before_title'  => '<h3 class="widget-title is-hidden">',
				'after_title'   => '</h3>',
			)
		);
		// register_sidebar(
		// 	array(
		// 		'name'          => __( 'Hero Slider', 'sgds' ),
		// 		'id'            => 'hero',
		// 		'description'   => __( 'Hero slider area. Place two or more widgets here and they will slide!', 'sgds' ),
		// 		'before_widget' => '<div class="carousel-item">',
		// 		'after_widget'  => '</div>',
		// 		'before_title'  => '',
		// 		'after_title'   => '',
		// 	)
		// );
		// register_sidebar(
		// 	array(
		// 		'name'          => __( 'Hero Canvas', 'sgds' ),
		// 		'id'            => 'herocanvas',
		// 		'description'   => __( 'Full size canvas hero area for Bootstrap and other custom HTML markup', 'sgds' ),
		// 		'before_widget' => '',
		// 		'after_widget'  => '',
		// 		'before_title'  => '',
		// 		'after_title'   => '',
		// 	)
		// );
		// register_sidebar(
		// 	array(
		// 		'name'          => __( 'Top Full', 'sgds' ),
		// 		'id'            => 'statichero',
		// 		'description'   => __( 'Full top widget with dynamic grid', 'sgds' ),
		// 		'before_widget' => '<div id="%1$s" class="footer-widget %2$s dynamic-classes">',
		// 		'after_widget'  => '</div><!-- .static-hero-widget -->',
		// 		'before_title'  => '<h3 class="widget-title">',
		// 		'after_title'   => '</h3>',
		// 	)
		// );
		// register_sidebar( array(
		// 		'name'          => esc_html__( 'Sidebar', 'sgds' ),
		// 		'id'            => 'sidebar-1',
		// 		'description'   => esc_html__( 'Add widgets here.', 'sgds' ),
		// 		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		// 		'after_widget'  => '</section>',
		// 		'before_title'  => '<h2 class="widget-title">',
		// 		'after_title'   => '</h2>',
		// 		) 
		// );
		register_sidebar(
			array(
				'name'          => __( 'Footer Column Area', 'sgds' ),
				'id'            => 'footerfull',
				'description'   => __( 'SGDS Footer Columns', 'sgds' ),
				'before_widget' => '<div class="footer-widget %2$s dynamic-classes">',
				'after_widget'  => '</div><!-- .footer-widget -->',
				'before_title'  => '<p class="footer-link-title margin--bottom">',
				'after_title'   => '</p>'
			)
		);
		register_sidebar(
			array(
				'name'          => __( 'SGDS Footer Contact Area', 'sgds' ),
				'id'            => 'footerarea1',
				'description'   => __( 'Contain links for contacts and report vulnarability', 'sgds' ),
				'before_widget' => '<li class="is-inline-block-desktop-only"><p>',
				'after_widget'  => '</p></li><!-- .footer-widget -->',
				'before_title'  => '<p class="is-hidden">',
				'after_title'   => '</p>'
			)
		);
		register_sidebar(
			array(
				'name'          => __( 'SGDS Footer Bottom Link Area', 'sgds' ),
				'id'            => 'footerarea2',
				'description'   => __( 'Contain links for privacy', 'sgds' ),
				'before_widget' => '<li>',
				'after_widget'  => '</li><!-- .footer-widget -->',
				'before_title'  => '<p class="is-hidden">',
				'after_title'   => '</p>'
			)
		);
	}
} // endif function_exists( 'sgds_widgets_init' ).

